@@ -46,7 +46,7 @@ doubling the child's number and adding one.
 use strict;
 use warnings;
 
-our $VERSION = '0.0.5';
+our $VERSION = '1.0.1';
 
 require Exporter;
 our @ISA = qw[Exporter];
@@ -62,7 +62,7 @@ use Type::Utils qw( declare as where inline_as coerce from );
 my $PositiveInt = declare
   as        Int,
   where     {  $_ > 0  },
-  inline_as { "$_ =~ /^[0-9]+\$/ and $_ > 0" };
+  inline_as { "defined $_ and $_ =~ /^[0-9]+\$/ and $_ > 0" };
 
 use overload
   '""' => sub { $_[0]->ahnentafel },
